aboutsummaryrefslogtreecommitdiff
path: root/cast/streaming/sender_session.h
diff options
context:
space:
mode:
Diffstat (limited to 'cast/streaming/sender_session.h')
-rw-r--r--cast/streaming/sender_session.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/cast/streaming/sender_session.h b/cast/streaming/sender_session.h
index dce7ce2a..7702b490 100644
--- a/cast/streaming/sender_session.h
+++ b/cast/streaming/sender_session.h
@@ -20,7 +20,7 @@
#include "cast/streaming/sender.h"
#include "cast/streaming/sender_packet_router.h"
#include "cast/streaming/session_config.h"
-#include "cast/streaming/session_messager.h"
+#include "cast/streaming/session_messenger.h"
#include "json/value.h"
#include "util/json/json_serialization.h"
@@ -230,10 +230,10 @@ class SenderSession final {
// This session's configuration.
Configuration config_;
// The session messager, which uses the message port for sending control
// messages. For message formats, see
// cast/protocol/castv2/streaming_schema.json.
- SenderSessionMessager messager_;
+ SenderSessionMessenger messenger_;
// The packet router used for RTP/RTCP messaging across all senders.
SenderPacketRouter packet_router_;
@@ -230,10 +230,10 @@ class SenderSession final {
// This session's configuration.
Configuration config_;
- // The session messager, which uses the message port for sending control
+ // The session messenger, which uses the message port for sending control
// messages. For message formats, see
// cast/protocol/castv2/streaming_schema.json.